
gitsane | Utility for managing local git repositories
-----------------------------------------------------------

PACKAGE: gitsane

`gitsane`: Performs the following functions on your local machine:

* updates all repositories
* updates specific branches, if present in the repo
* Recreates a complex set of git repositories and their nested directory structure on a new machine 
